@@ -34,7 +34,7 @@
 #include "sim/callback.h"
 #include "sim/sim.h"
 #include "gdb/signals.h"
-#include "gdb/sim-aarch64.h"
+#include "sim/sim-aarch64.h"
 
 #include "sim-main.h"
 #include "sim-options.h"
@@ -42,6 +42,8 @@
 #include "simulator.h"
 #include "sim-assert.h"
 
+#include "aarch64-sim.h"
+
 /* Filter out (in place) symbols that are useless for disassembly.
    COUNT is the number of elements in SYMBOLS.
    Return the number of useful symbols. */
@@ -346,7 +348,8 @@ sim_open (SIM_OPEN_KIND                  kind,
   current_alignment = NONSTRICT_ALIGNMENT;
 
   /* Perform the initialization steps one by one.  */
-  if (sim_cpu_alloc_all (sd, 1) != SIM_RC_OK
+  if (sim_cpu_alloc_all_extra (sd, 0, sizeof (struct aarch64_sim_cpu))
+      != SIM_RC_OK
       || sim_pre_argv_init (sd, argv[0]) != SIM_RC_OK
       || sim_parse_args (sd, argv) != SIM_RC_OK
       || sim_analyze_program (sd, STATE_PROG_FILE (sd), abfd) != SIM_RC_OK
